<?php
/** Serbian (Српски / Srpski)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Misos
 * @author Terik
 * @author Жељко Тодоровић
 * @author Михајло Анђелковић
 */

$fallback = 'sr-ec';
$linkTrail = '/^([abvgdđežzijklljmnnjoprstćufhcčdžšабвгдђежзијклљмнњопрстћуфхцчџш]+)(.*)$/usD';

$messages = array(
# Vector skin
'vector-view-viewsource' => 'Изворник',

# Special:LinkSearch
'linksearch'       => 'Претрага интернет веза',
'linksearch-text'  => 'Џокери као што су "*.wikipedia.org" могу да се користе.
Подржани протоколи: <tt>$1</tt>',
'linksearch-line'  => '$1 повезана са $2',
'linksearch-error' => 'Џокери могу да се појављују само на почетку домена.',

# Special:Log/newusers
'newuserlogpage'           => 'историја креирања корисника',
'newuserlogpagetext'       => 'Ово је историја скорашњих креирања корисника.',
'newuserlog-create2-entry' => 'направио налог за $1',

);
